#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Migration des logos des clubs :
- récupère les logos des clubs dans le dossier media/logos-clubs/
- les ajoute à la db (dans Club.logo)
Cela revient donc à juste ajouter un lien vers le logo dans la base de données.
"""

import os
from os.path import isfile
from os.path import join
import shutil

from django.conf import settings
from django.core.files.images import ImageFile
from django.core.management.base import BaseCommand

from club.models import Club


class Command(BaseCommand):
    help = "Migrer les logos des clubs"

    def handle(self, *args, **options):
        chemin = f"{settings.MEDIA_ROOT}/logos-clubs/"
        chemin_back = join(chemin, "backups")
        chemin_succes = join(chemin, "succes")

        # récupère la liste des logos présents
        logos = [_ for _ in os.listdir(chemin) if isfile(join(chemin, _))]
        if not logos:
            print("Aucun logo à migrer.")
        else:
            # créer un dossier de backup
            if not os.path.exists(chemin_back):
                print("Création du dossier de backup.")
                os.mkdir(chemin_back)
            # créer un dossier temporaire de succès
            if not os.path.exists(chemin_succes):
                print("Création du dossier des logos migrés.")
                os.mkdir(chemin_succes)

        for logo in logos:
            # déplace les logos dans le dossier de backup
            shutil.move(join(chemin, logo), chemin_back)
            # sauvegarde le fichier
            with open(join(chemin_back, logo), mode="rb") as f:
                fichier = ImageFile(f)
                # trouve le club correspondant
                club_ident = "-".join(logo.split("-")[:-1])
                club_ecole = logo.split("-")[-1][:-4]
                try:
                    club = Club.objects.get(ident=club_ident, ecole__ident=club_ecole)
                    club.logo = fichier
                    club.save()
                    shutil.move(join(chemin_back, logo), chemin_succes)
                    print(f"Le logo du club {club_ident} a bien été sauvegardé.")
                except Club.DoesNotExist:
                    print(f"Le club {club_ident} n'a pas été trouvé.")
